<?php
/**
* News Bulletin functions and definitions
*
* @link https://developer.news_bulletin.org/themes/basics/theme-functions/
*
* @package news_bulletin
*/
if ( ! function_exists( 'news_bulletin_setup' ) ) :
	/**
	* Sets up theme defaults and registers support for various WordPress features.
	*
	* Note that this function is hooked into the after_setup_theme hook, which
	* runs before the init hook. The init hook is too late for some features, such
	* as indicating support for post thumbnails.
	*/
	function news_bulletin_setup() {
		/*remove block editor widget */

		 remove_theme_support( 'widgets-block-editor' );
		/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on News Miles, use a find and replace
		* to change 'news-bulletin' to the name of your theme in all the template files.
		*/
		load_theme_textdomain( 'news-bulletin' );
		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );
		/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
		add_theme_support( 'title-tag' );
		/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
		add_theme_support( 'post-thumbnails' );
		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'news-bulletin' ),
			'top-menu' => esc_html__( 'Top Menu', 'news-bulletin' ),
			'buttom-menu' => esc_html__( 'Buttom Menu', 'news-bulletin' ),
		) );
		/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );
		/*

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'news_bulletin_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );
		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );
		/**
		* Add support for core custom logo.
		*
		* @link https://codex.news_bulletin.org/Theme_Logo
		*/
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
		add_image_size( 'news-bulletin-big', 549, 465 );
		add_image_size( 'news-bulletin-feature1', 470.5, 280 );
		add_image_size( 'news-bulletin-feature2', 233.75, 182 );
		add_image_size( 'news-bulletin-latest', 230, 153 );
		add_image_size( 'news-bulletin-multicat', 360, 239.5 );
		add_image_size( 'news-bulletin-multicat-small', 100, 75 );
		add_image_size( 'news-bulletin-big-image', 360, 340 );
		add_image_size( 'news-bulletin-small-image', 100, 75 );
		/**
		* Register support for Gutenberg wide width in your theme
		*/
	add_theme_support( 'align-wide' );

	}
endif;
add_action( 'after_setup_theme', 'news_bulletin_setup' );
/**
* Set the content width in pixels, based on the theme's design and stylesheet.
*
* Priority 0 to make it available to lower priority callbacks.
*
* @global int $content_width
*/
function news_bulletin_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'news_bulletin_content_width', 640 );
}
add_action( 'after_setup_theme', 'news_bulletin_content_width', 0 );
/**
* Register widget area.
*
* @link https://developer.news_bulletin.org/themes/functionality/sidebars/#registering-a-sidebar
*/
function news_bulletin_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Advertisement Area', 'news-bulletin' ),
		'id'            => 'advertisement',
		'description'   => esc_html__( 'Add widgets here.', 'news-bulletin' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '',
		'after_title'   => '',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'news-bulletin' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'news-bulletin' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="head-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Top HomePage Section with No Sidebar  ', 'news-bulletin' ),
		'id'            => 'home-sections-1',
		'description'   => esc_html__( 'Add  widgets here what you want in home widgets.', 'news-bulletin' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="head-title"><span>',
		'after_title'   => '</span></h3>',
	) );
register_sidebar( array(
'name'          => esc_html__( 'HomePage Section ', 'news-bulletin' ),
'id'            => 'home-sections',
'description'   => esc_html__( 'Add  widgets here what you want in home widgets.', 'news-bulletin' ),
'before_widget' => '<section id="%1$s" class="widget %2$s">',
'after_widget'  => '</section>',
		'before_title'  => '<h3 class="head-title"><span>',
		'after_title'   => '</span></h3>',
) );
	register_sidebar( array(
		'name'          => esc_html__( 'HomePage Section with No Sidebar  ', 'news-bulletin' ),
		'id'            => 'home-sections-2',
		'description'   => esc_html__( 'Add  widgets here what you want in home widgets.', 'news-bulletin' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="head-title"><span>',
		'after_title'   => '</span></h3>',
	) );
	register_sidebar(array(
		'name' => esc_html__('Footer1 ', 'news-bulletin'),
		'id' => 'footer1',
		'description' => esc_html__('Add widgets here.', 'news-bulletin'),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="head-title"><span>',
		'after_title'   => '</span></h3>',
	));
	register_sidebar(array(
		'name' => esc_html__('Footer2 ', 'news-bulletin'),
		'id' => 'footer2',
		'description' => esc_html__('Add widgets here.', 'news-bulletin'),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="head-title"><span>',
		'after_title'   => '</span></h3>',
	));
	register_sidebar(array(
		'name' => esc_html__('Footer3 ', 'news-bulletin'),
		'id' => 'footer3',
		'description' => esc_html__('Add widgets here.', 'news-bulletin'),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="head-title"><span>',
		'after_title'   => '</span></h3>',
	));
	register_sidebar(array(
		'name' => esc_html__('Footer4 ', 'news-bulletin'),
		'id' => 'footer4',
		'description' => esc_html__('Add widgets here.', 'news-bulletin'),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="head-title"><span>',
		'after_title'   => '</span></h3>',
	));
	
}
add_action( 'widgets_init', 'news_bulletin_widgets_init' );
/**
* Enqueue scripts and styles.
*/
function news_bulletin_scripts() {
	wp_enqueue_style( 'fontawesome', get_template_directory_uri() .'/assets/fontawesome/css/all.min.css');
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() .'/assets/css/bootstrap.min.css');
	wp_enqueue_style( 'animate', get_template_directory_uri() .'/assets/css/animate.css');
	wp_enqueue_style( 'owl-carousel', get_template_directory_uri() .'/assets/css/owl.carousel.min.css');
	wp_enqueue_style( 'owl-theme-default', get_template_directory_uri() .'/assets/css/owl.theme.default.min.css');
	wp_enqueue_style( 'news-bulletin-blocks', get_template_directory_uri() .'/assets/css/blocks.min.css');
    wp_enqueue_style( 'slick', get_template_directory_uri() .'/assets/css/slick.css');
    wp_enqueue_style( 'slick-theme', get_template_directory_uri() .'/assets/css/slick-theme.css');
    wp_enqueue_style( 'news-bulletin-style', get_stylesheet_uri() );
	wp_enqueue_style( 'news-bulletin-media-responsive', get_template_directory_uri() .'/assets/css/media-responsive.css');
    wp_enqueue_script( 'silck', get_template_directory_uri() . '/assets/js/slick.min.js', array('jquery'), '20151215', true );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array('jquery'), '20151215', true );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.min.js', array('jquery'), '20151215', true );
	wp_enqueue_script( 'theia-sticky-sidebar', get_template_directory_uri() . '/assets/js/theia-sticky-sidebar.js', array('jquery'), '4.5.0' );
	wp_enqueue_script( 'news-bulletin-custom', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), '20151215', true );
	wp_enqueue_script( 'news-bulletin-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
	wp_enqueue_script( 'news-bulletin-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'news_bulletin_scripts' );
/*admin enqueue */
if (!function_exists('news_bulletin_admin_css_enqueue_new_post')) :
	function news_bulletin_admin_css_enqueue_new_post($hook)
	{
		if ('post-new.php' != $hook) {
			return;
		}
		wp_enqueue_style('news-bulletin-admin', get_template_directory_uri() . '/assets/css/admin.css', array(), '2.0.0');

	}
	add_action('admin_enqueue_scripts', 'news_bulletin_admin_css_enqueue_new_post');
endif;
/**
* Widget assets for image upload
*
* @return void
*/
add_action('admin_enqueue_scripts', 'news_bulletin_widgets_backend_enqueue');
function news_bulletin_widgets_backend_enqueue()
{
	wp_register_script('news-bulletin-custom-widgets', get_template_directory_uri() . '/assets/js/widget.js', array('jquery'), true);
	wp_enqueue_media();
	wp_enqueue_script('news-bulletin-custom-widgets');
}
/**
* Implement the Custom Header feature.
*/
require get_template_directory() . '/inc/custom-header.php';
/**
* Custom template tags for this theme.
*/
require get_template_directory() . '/inc/template-tags.php';
/**
* Functions which enhance the theme by hooking into WordPress.
*/
require get_template_directory() . '/inc/template-functions.php';
/**
* All file loader.
*/
require get_template_directory() . '/inc/ample-themes/loadalloption.php';;
/**
* Customizer additions.
*/
require get_template_directory() . '/inc/customizer.php';
/**
* Load Jetpack compatibility file.
*/
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}
/**
* Load WooCommerce compatibility file.
*/
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

//all required theme function loader
require get_template_directory() . '/inc/required-theme-function.php';

//admin notice loader
if ( is_admin() ) {
    require get_template_directory() . '/inc/admin-notice/class-notice-handler.php';
}
/*theme activation plugins*/
require get_template_directory() . '/library/TGM/class-tgm-plugin-activation.php';
require get_template_directory() . '/library/TGM/plugin-slug.php';