<?php
/**
 * Utility function to check if a gravatar exists for a given email or id
 * @param int|string|object $id_or_email A user ID,  email address, or comment object
 * @return bool if the gravatar exists or not
 * https://gist.github.com/justinph/5197810#file-validate_gravatar-php
 */
function news_bulletin_validate_gravatar($id_or_email) {
//id or email code borrowed from wp-includes/pluggable.php
    $email = '';
    if ( is_numeric($id_or_email) ) {
        $id = (int) $id_or_email;
        $user = get_userdata($id);
        if ( $user )
            $email = $user->user_email;
    } elseif ( is_object($id_or_email) ) {
// No avatar for pingbacks or trackbacks
        $allowed_comment_types = apply_filters( 'get_avatar_comment_types', array( 'comment' ) );
        if ( ! empty( $id_or_email->comment_type ) && ! in_array( $id_or_email->comment_type, (array) $allowed_comment_types ) )
            return false;
        if ( !empty($id_or_email->user_id) ) {
            $id = (int) $id_or_email->user_id;
            $user = get_userdata($id);
            if ( $user)
                $email = $user->user_email;
        } elseif ( !empty($id_or_email->comment_author_email) ) {
            $email = $id_or_email->comment_author_email;
        }
    } else {
        $email = $id_or_email;
    }
    $hashkey = md5(strtolower(trim($email)));
    $uri = 'http://www.gravatar.com/avatar/' . $hashkey . '?d=404';
    $data = wp_cache_get($hashkey);
    if (false === $data) {
        $response = wp_remote_head($uri);
        if( is_wp_error($response) ) {
            $data = 'not200';
        } else {
            $data = $response['response']['code'];
        }
        wp_cache_set($hashkey, $data, $group = '', $expire = 60*5);
    }
    if ($data == '200'){
        return true;
    } else {
        return false;
    }
}
//image define
if ( ! function_exists( 'news_bulletin_post_thumbnail' ) ) :
    function  news_bulletin_post_thumbnail(){
        if (has_post_thumbnail()) {
            $image_id = get_post_thumbnail_id();
            $image_url = wp_get_attachment_image_src($image_id, 'large', true);
            ?>
            <a href="<?php the_permalink(); ?>"><img class="img-responsive"
                                                     src="<?php echo esc_url($image_url[0]); ?>"
                                                     alt="<?php the_title_attribute(); ?>"/></a>
        <?php }
    }
endif;
/*for sidebar adding options**/
function news_bulletin_names( $classes ) {
// add 'class-name' to the $classes array
    $sidebardesignlayout = esc_attr( get_post_meta(get_the_ID(), 'news_bulletin_sidebar_layout', true) );
    if (is_singular() && $sidebardesignlayout != "default-sidebar")
    {
        $sidebardesignlayout = esc_attr( get_post_meta(get_the_ID(), 'news_bulletin_sidebar_layout', true) );
    } else
    {
        $sidebardesignlayout = esc_attr(news_bulletin_get_option('news_bulletin_sidebar_layout_option' ));
    }
    $classes[] = $sidebardesignlayout;
    return $classes;
}
add_filter( 'body_class', 'news_bulletin_names' );
/* =====adding menu last and first class==========*/
function news_bulletin_first_and_last_menu_class($items) {
    $items[1]->classes[] = 'first-menu';
    $items[count($items)]->classes[] = 'last-menu';
    return $items;
}
add_filter('wp_nav_menu_objects', 'news_bulletin_first_and_last_menu_class');
/*for description highlight in menu */
/**
 * Add arrows to menu items
 * @author Bill Erickson
 * @link http://www.billerickson.net/code/add-arrows-to-menu-items/
 *
 * @param string $item_output, HTML output for the menu item
 * @param object $item, menu item object
 * @param int $depth, depth in menu structure
 * @param object $args, arguments passed to wp_nav_menu()
 * @return string $item_output
 */
if (!function_exists('news_bulletin_add_menu_description')) :
    function news_bulletin_add_menu_description( $item_output, $item, $depth, $args ) {
        if( 'primary' == $args->theme_location  && $item->description )
            $item_output = str_replace( '</a>', '<span class="menu-description">' . $item->description . '</span></a>', $item_output );
        return $item_output;
    }
endif;
add_filter( 'walker_nav_menu_start_el', 'news_bulletin_add_menu_description', 10, 4 );

/* for breadcumb */
add_filter('bcn_breadcrumb_title', function($title, $type, $id) {
    if ($type[0] === 'home') {
        $title = get_the_title(get_option('page_on_front'));
    }
    return $title;
}, 42, 3);
